Exception: OpenASN::UpdateError
- Defined in:
- lib/openasn/errors.rb
Overview
Canonical refresh failed in a way worth surfacing to the caller of OpenASN.update! (Tier B sources never raise — they keep stale data).
Canonical refresh failed in a way worth surfacing to the caller of OpenASN.update! (Tier B sources never raise — they keep stale data).